@@ -297,7 +297,7 @@ typedef struct _AbacusRec {
 
 struct moveType {
 	char *code;
-	unsigned int lines;
+	size_t lines;
 	char **lineText;
 };
 
